@@ -11,6 +11,7 @@
         ## Create a webhook on a specific repository   ## 
          ###############################################################
  """
+import time
 import requests
 import json
 import os 
@@ -159,18 +160,34 @@ def init():
         #   pull
           response = requests.get('http://35.225.89.124/push_commit')
           res=response.content
-          res=str(res)
-          index=res.index("Repository")
-          index1 = data.index(":",index+1)
-          index2 = data.index("\n",index1+1)
-          repoN = data[index1 + 1:index2]
-          print("repo name is ",repoN)
-          print(len(res))
-          val=len(res)
-          if val >0:
-            repo = git.Repo(path)
-            origin = repo.remote(name='origin')
-            res=origin.pull()
+        #   res=str(res)
+        #   index=res.index("Repository")
+        #   index1 = data.index(":",index+1)
+        #   index2 = data.index("\n",index1+1)
+        #   repoN = data[index1 + 1:index2]
+        #   print("repo name is ",repoN)
+          for i in range(3):
+                response = requests.get('http://35.225.89.124/push_commit')
+                res=response.content
+                print(res)
+                val=len(res)
+                print(val)
+                # data=str(res)
+                print("inside except")
+                # index=data.index("Repository")
+                # index1 = data.index(":",index+1)
+                # index2 = data.index("\n",index1+1)
+                # repoN = data[index1 + 1:index2]
+                # print("repo name is ",repoN)
+                if val >0:
+                    repo = git.Repo(path)
+                    origin = repo.remote(name='origin')
+                    res=origin.pull()
+                    print("pull succeessfull")
+                    time.sleep(10)
+                else:
+                    print("no files to pull")
+                    time.sleep(10)
           response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name})
            #success , project id , repo name , current date and time , email id
           print("status code is ",response2.status_code)
@@ -179,27 +196,32 @@ def init():
             print("webhook already exists on this repository ")
 
             #   pull
-            response = requests.get('http://35.225.89.124/push_commit')
-            res=response.content
-            print(res)
-            val=len(res)
-            print(val)
-            data=str(res)
-            print("inside except")
-            index=data.index("Repository")
-            index1 = data.index(":",index+1)
-            index2 = data.index("\n",index1+1)
-            repoN = data[index1 + 1:index2]
-            print("repo name is ",repoN)
-            if val >0:
-                repo = git.Repo(path)
-                origin = repo.remote(name='origin')
-                res=origin.pull()
-                print("pull succeessfull")
-            else:
-                print("no files to pull")
-            time = datetime.datetime.now()
-            response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':time,'user_name':username})
+
+            for i in range(3):
+                response = requests.get('http://35.225.89.124/push_commit')
+                res=response.content
+                print(res)
+                val=len(res)
+                print(val)
+                # data=str(res)
+                print("inside except")
+                # index=data.index("Repository")
+                # index1 = data.index(":",index+1)
+                # index2 = data.index("\n",index1+1)
+                # repoN = data[index1 + 1:index2]
+                # print("repo name is ",repoN)
+                if val >0:
+                    repo = git.Repo(path)
+                    origin = repo.remote(name='origin')
+                    res=origin.pull()
+                    print("pull succeessfull")
+                    time.sleep(10)
+                else:
+                    print("no files to pull")
+                    time.sleep(10)
+
+            curtime = datetime.datetime.now()
+            response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username})
            #success , project id , repo name , current date and time , email id'
             print("status code is ",response2.status_code)
 
